import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import InvoicePaymentStatusChange
from lago_python_client.clients.base_client import LagoApiError


def update_invoice_object():
    return InvoicePaymentStatusChange(payment_status='failed')


def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    my_data_path = os.path.join(this_dir, 'fixtures/invoice.json')

    with open(my_data_path, 'r') as invoice_response:
        return invoice_response.read()


def mock_collection_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/invoice_index.json')

    with open(data_path, 'r') as invoice_response:
        return invoice_response.read()


class TestInvoiceClient(unittest.TestCase):
    def test_valid_update_invoice_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/invoices/5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba',
                           text=mock_response())
            response = client.invoices().update(update_invoice_object(), '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')

        self.assertEqual(response.lago_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
        self.assertEqual(response.payment_status, 'failed')

    def test_invalid_update_invoice_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/invoices/5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba',
                           status_code=401,
                           text='')

            with self.assertRaises(LagoApiError):
                client.invoices().update(update_invoice_object(), '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')

    def test_valid_find_invoice_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        identifier = '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/invoices/' + identifier, text=mock_response())
            response = client.invoices().find(identifier)

        self.assertEqual(response.lago_id, identifier)

    def test_invalid_find_invoice_request(self):
        client = Client(api_key='invalid')
        identifier = '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/invoices/' + identifier, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.invoices().find(identifier)

    def test_valid_find_all_invoice_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/invoices', text=mock_collection_response())
            response = client.invoices().find_all()

        self.assertEqual(response['invoices'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1111')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_valid_find_all_invoice_request_with_options(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/invoices?per_page=2&page=1', text=mock_collection_response())
            response = client.invoices().find_all({'per_page': 2, 'page': 1})

        self.assertEqual(response['invoices'][1].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1222')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_invalid_find_all_invoice_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/invoices', status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.invoices().find_all()

    def test_valid_download_invoice_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST',
                            'https://api.getlago.com/api/v1/invoices/5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba/download',
                            text=mock_response())
            response = client.invoices().download('5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')

        self.assertEqual(response.lago_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')


if __name__ == '__main__':
    unittest.main()



from .base_client import BaseClient
from lago_python_client.models.coupon import CouponResponse
from typing import Dict


class CouponClient(BaseClient):
    def api_resource(self):
        return 'coupons'

    def root_name(self):
        return 'coupon'

    def prepare_response(self, data: Dict):
        return CouponResponse.parse_obj(data)



from tests.test_event_client import TestEventClient
from tests.test_subscription_client import TestSubscriptionClient
from tests.test_customer_client import TestCustomerClient
from tests.test_applied_coupon_client import TestAppliedCouponClient
from tests.test_applied_add_on_client import TestAppliedAddOnClient
from tests.test_billable_metric_client import TestBillableMetricClient
from tests.test_coupon_client import TestCouponClient
from tests.test_group_client import TestGroupClient
from tests.test_plan_client import TestPlanClient
from tests.test_add_on_client import TestAddOnClient
from tests.test_organization_client import TestOrganizationClient
from tests.test_invoice_client import TestInvoiceClient
from tests.test_webhook_client import TestWebhookClient
from tests.test_client import TestClient
from tests.test_wallet_client import TestWalletClient
from tests.test_wallet_transaction_client import TestWalletTransactionClient
from tests.test_credit_note_client import TestCreditNoteClient



from pydantic import BaseModel, Field
from typing import Optional


class Group(BaseModel):
    lago_id: Optional[str]
    key: Optional[str]
    value: Optional[str]

class GroupResponse(BaseModel):
    lago_id: str
    key: str
    value: str



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models.invoice import FeeResponse
from lago_python_client.models.credit_note import Item, Items, CreditNote, CreditNoteUpdate
from lago_python_client.clients.base_client import LagoApiError

def credit_note_object():
    item1 = Item(
        fee_id="fee_id_1",
        credit_amount_cents=10,
        refund_amount_cents=10,
    )

    item2 = Item(
        fee="fee_id_2",
        credit_amount_cents=5,
        refund_amount_cents=5,
    )

    return CreditNote(
        lago_id="credit_note_id",
        reason= 'other',
        items= Items(__root__=[item1, item2])
    )

def credit_note_update_object():
    return CreditNoteUpdate(refund_status='pending')

def mock_response():
    current_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(current_dir, 'fixtures/credit_note.json')

    with open(data_path, 'r') as credit_note_response:
        return credit_note_response.read()

def mock_collection_response():
    current_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(current_dir, 'fixtures/credit_note_index.json')

    with open(data_path, 'r') as credit_notes_response:
        return credit_notes_response.read()

class TestCreditNoteClient(unittest.TestCase):
    def test_valid_find_credit_note_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        identifier = '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/credit_notes/' + identifier, text=mock_response())
            response = client.credit_notes().find(identifier)

        self.assertEqual(response.lago_id, identifier)

    def test_invalid_find_invoice_request(self):
        client = Client(api_key='invalid')
        identifier = '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/credit_notes/' + identifier, status_code=404, text='')

        with self.assertRaises(LagoApiError):
            client.credit_notes().find(identifier)

    def test_valid_find_all_credit_notes_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/credit_notes', text=mock_collection_response())
            response = client.credit_notes().find_all({'per_page': 2, 'page': 1})

        self.assertEqual(response['credit_notes'][0].lago_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_valid_download_credit_note_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST',
                            'https://api.getlago.com/api/v1/credit_notes/5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba/download',
                            text=mock_response())
            response = client.credit_notes().download('5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')

        self.assertEqual(response.lago_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')

    def test_valid_create_credit_note_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/credit_notes', text=mock_response())
            response = client.credit_notes().create(credit_note_object())

        self.assertEqual(response.lago_id, "5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba")
        self.assertEqual(response.refund_status, 'pending')

    def test_invalid_create_credit_note_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/credit_notes', status_code=422, text='')

            with self.assertRaises(LagoApiError):
                client.credit_notes().create(credit_note_object())

    def test_valid_update_credit_note_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        credit_note_id = 'credit-note-id'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/credit_notes/' + credit_note_id,
                           text=mock_response())
            response = client.credit_notes().update(credit_note_update_object(), credit_note_id)

        self.assertEqual(response.lago_id, "5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba")
        self.assertEqual(response.refund_status, 'pending')

    def test_valid_void_credit_note_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        credit_note_id = 'credit-note-id'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/credit_notes/' + credit_note_id + '/void',
                           text=mock_response())
            response = client.credit_notes().void(credit_note_id)

        self.assertEqual(response.lago_id, "5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba")
        self.assertEqual(response.refund_status, 'pending')

if __name__ == '__main__':
    unittest.main()



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import BillableMetric, BillableMetricGroup
from lago_python_client.clients.base_client import LagoApiError


def billable_metric_object():
    return BillableMetric(
        name='name',
        code='code_first',
        description='desc',
        aggregation_type='sum_agg',
        field_name='amount_sum',
        group=group()
    )

def group():
    return BillableMetricGroup(key='country', values=['france', 'italy', 'spain'])

def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/billable_metric.json')

    with open(data_path, 'r') as billable_metric_response:
        return billable_metric_response.read()


def mock_collection_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/billable_metric_index.json')

    with open(data_path, 'r') as billable_metric_response:
        return billable_metric_response.read()


class TestBillableMetricClient(unittest.TestCase):
    def test_valid_create_billable_metric_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/billable_metrics', text=mock_response())
            response = client.billable_metrics().create(billable_metric_object())

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, 'bm_code')
        self.assertEqual(response.group, group())

    def test_invalid_create_billable_metric_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/billable_metrics', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.billable_metrics().create(billable_metric_object())

    def test_valid_update_billable_metric_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'bm_code'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/billable_metrics/' + code,
                           text=mock_response())
            response = client.billable_metrics().update(billable_metric_object(), code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_update_billable_metric_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/billable_metrics/' + code,
                           status_code=401,
                           text='')

            with self.assertRaises(LagoApiError):
                client.billable_metrics().update(billable_metric_object(), code)

    def test_valid_find_billable_metric_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'bm_code'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/billable_metrics/' + code, text=mock_response())
            response = client.billable_metrics().find(code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_find_billable_metric_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/billable_metrics/' + code, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.billable_metrics().find(code)

    def test_valid_destroy_billable_metric_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'bm_code'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/billable_metrics/' + code, text=mock_response())
            response = client.billable_metrics().destroy(code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_destroy_billable_metric_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/billable_metrics/' + code, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.billable_metrics().destroy(code)

    def test_valid_find_all_billable_metric_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/billable_metrics', text=mock_collection_response())
            response = client.billable_metrics().find_all()

        self.assertEqual(response['billable_metrics'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1000')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_valid_find_all_billable_metric_request_with_options(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/billable_metrics?per_page=2&page=1', text=mock_collection_response())
            response = client.billable_metrics().find_all({'per_page': 2, 'page': 1})

        self.assertEqual(response['billable_metrics'][1].lago_id, 'b7ab2926-1de8-4428-9bcd-779314a11111')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_invalid_find_all_billable_metric_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/billable_metrics', status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.billable_metrics().find_all()


if __name__ == '__main__':
    unittest.main()



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import Plan, Charge, Charges
from lago_python_client.clients.base_client import LagoApiError


def plan_object():
    charge = Charge(
        billable_metric_id='id',
        charge_model='standard',
        amount_currency='EUR',
        group_properties = [
            {
                'group_id': 'id',
                'values': {
                    'amount': '0.22'
                }
            }
        ]
    )
    charges = Charges(__root__=[charge])

    return Plan(
        name='name',
        code='code_first',
        amount_cents=1000,
        amount_currency='EUR',
        description='desc',
        interval='weekly',
        pay_in_advance=True,
        charges=charges
    )

def graduated_plan_object():
    charge = Charge(
        billable_metric_id='id',
        charge_model='graduated',
        amount_currency='EUR',
        properties = {
            'graduated_ranges': [
                {
                    'to_value': 1,
                    'from_value': 0,
                    'flat_amount': "0",
                    'per_unit_amount': "0"
                },
                {
                    'to_value': None,
                    'from_value': 2,
                    'flat_amount': "0",
                    'per_unit_amount': "3200"
                }
            ]
        }
    )
    charges = Charges(__root__=[charge])

    return Plan(
        name='name',
        code='code_first',
        amount_cents=1000,
        amount_currency='EUR',
        description='desc',
        interval='weekly',
        pay_in_advance=True,
        charges = charges,
    )

def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/plan.json')

    with open(data_path, 'r') as plan_response:
        return plan_response.read()

def mock_graduated_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/graduated_plan.json')

    with open(data_path, 'r') as plan_response:
        return plan_response.read()


def mock_collection_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/plan_index.json')

    with open(data_path, 'r') as plan_response:
        return plan_response.read()


class TestPlanClient(unittest.TestCase):
    def test_valid_create_plan_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/plans', text=mock_response())
            response = client.plans().create(plan_object())

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, 'plan_code')

    def test_valid_create_graduated_plan_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/plans', text=mock_graduated_response())
            response = client.plans().create(graduated_plan_object())

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, 'plan_code')

    def test_invalid_create_plan_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/plans', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.plans().create(plan_object())

    def test_valid_update_plan_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'plan_code'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/plans/' + code,
                           text=mock_response())
            response = client.plans().update(plan_object(), code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_update_plan_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/plans/' + code,
                           status_code=401,
                           text='')

            with self.assertRaises(LagoApiError):
                client.plans().update(plan_object(), code)

    def test_valid_find_plan_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'plan_code'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/plans/' + code, text=mock_response())
            response = client.plans().find(code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)
        self.assertEqual(response.charges.__root__[0].charge_model, 'standard')

    def test_invalid_find_plan_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/plans/' + code, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.plans().find(code)

    def test_valid_destroy_plan_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'plan_code'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/plans/' + code, text=mock_response())
            response = client.plans().destroy(code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_destroy_plan_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/plans/' + code, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.plans().destroy(code)

    def test_valid_find_all_plan_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/plans', text=mock_collection_response())
            response = client.plans().find_all()

        self.assertEqual(response['plans'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1111')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_valid_find_all_plan_request_with_options(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/plans?per_page=2&page=1', text=mock_collection_response())
            response = client.plans().find_all({'per_page': 2, 'page': 1})

        self.assertEqual(response['plans'][1].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1222')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_invalid_find_all_plan_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/plans', status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.plans().find_all()


if __name__ == '__main__':
    unittest.main()



from pydantic import BaseModel, Field
from typing import Optional


class CustomerBillingConfiguration(BaseModel):
    payment_provider: Optional[str]
    provider_customer_id: Optional[str]
    sync: Optional[bool]
    vat_rate: Optional[float]
    sync_with_provider: Optional[bool]


class Customer(BaseModel):
    external_id: str
    address_line1: Optional[str]
    address_line2: Optional[str]
    city: Optional[str]
    country: Optional[str]
    currency: Optional[str]
    email: Optional[str]
    legal_name: Optional[str]
    legal_number: Optional[str]
    logo_url: Optional[str]
    name: str
    phone: Optional[str]
    state: Optional[str]
    timezone: Optional[str]
    url: Optional[str]
    zipcode: Optional[str]
    billing_configuration: Optional[CustomerBillingConfiguration]


class CustomerResponse(BaseModel):
    lago_id: str
    external_id: str
    address_line1: Optional[str]
    address_line2: Optional[str]
    city: Optional[str]
    country: Optional[str]
    currency: Optional[str]
    email: Optional[str]
    created_at: str
    legal_name: Optional[str]
    legal_number: Optional[str]
    logo_url: Optional[str]
    name: str
    phone: Optional[str]
    state: Optional[str]
    timezone: Optional[str]
    applicable_timezone: str
    url: Optional[str]
    zipcode: Optional[str]
    billing_configuration: Optional[CustomerBillingConfiguration]



from .base_client import BaseClient
from lago_python_client.models.wallet import WalletResponse
from typing import Dict


class WalletClient(BaseClient):
    def api_resource(self):
        return 'wallets'

    def root_name(self):
        return 'wallet'

    def prepare_response(self, data: Dict):
        return WalletResponse.parse_obj(data)



from pydantic import BaseModel, Field
from typing import Optional, List
from .customer import CustomerResponse
from .subscription import SubscriptionsResponse

class InvoicePaymentStatusChange(BaseModel):
    payment_status: str

class InvoiceItemResponse(BaseModel):
    type: Optional[str]
    code: Optional[str]
    name: Optional[str]

class FeeResponse(BaseModel):
    lago_id: Optional[str]
    item: Optional[InvoiceItemResponse]
    amount_cents: Optional[int]
    amount_currency: Optional[str]
    vat_amount_cents: Optional[int]
    vat_amount_currency: Optional[str]
    units: Optional[float]
    events_count: Optional[int]

class FeesResponse(BaseModel):
    __root__: List[FeeResponse]

class CreditResponse(BaseModel):
    amount_cents: Optional[int]
    amount_currency: Optional[str]
    item: Optional[InvoiceItemResponse]

class CreditsResponse(BaseModel):
    __root__: List[CreditResponse]

class InvoiceResponse(BaseModel):
    lago_id: str
    sequential_id: int
    issuing_date: Optional[str]
    invoice_type: str
    payment_status: str
    amount_cents: int
    amount_currency: str
    vat_amount_cents: int
    vat_amount_currency: str
    total_amount_cents: int
    total_amount_currency: str
    file_url: Optional[str]
    customer: Optional[CustomerResponse]
    subscriptions: Optional[SubscriptionsResponse]
    fees: Optional[FeesResponse]
    credits: Optional[CreditsResponse]



from pydantic import BaseModel, Field
from typing import Optional, List


class Subscription(BaseModel):
    plan_code: Optional[str]
    external_customer_id: Optional[str]
    name: Optional[str]
    external_id: Optional[str]
    subscription_date: Optional[str]
    billing_time: Optional[str]


class SubscriptionResponse(BaseModel):
    lago_id: str
    lago_customer_id: Optional[str]
    external_customer_id: Optional[str]
    canceled_at: Optional[str]
    created_at: Optional[str]
    plan_code: Optional[str]
    started_at: Optional[str]
    status: Optional[str]
    name: Optional[str]
    external_id: Optional[str]
    billing_time: Optional[str]
    terminated_at: Optional[str]
    subscription_date: Optional[str]
    previous_plan_code: Optional[str]
    next_plan_code: Optional[str]
    downgrade_plan_date: Optional[str]

class SubscriptionsResponse(BaseModel):
    __root__: List[SubscriptionResponse]



import unittest
import requests_mock
import os

from lago_python_client.client import Client

def mock_collection_response():
    current_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(current_dir, 'fixtures/group_index.json')

    with open(data_path, 'r') as groups_response:
        return groups_response.read()

class TestGroupClient(unittest.TestCase):
    def test_valid_find_all_groups_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/billable_metrics/bm_code/groups', text=mock_collection_response())
            response = client.groups().find_all('bm_code', {'per_page': 2, 'page': 1})

        self.assertEqual(response['groups'][0].lago_id, '12345678-1de8-4428-9bcd-779314ac1111')
        self.assertEqual(response['meta']['current_page'], 1)


if __name__ == '__main__':
    unittest.main()



import requests
import json

from pydantic import BaseModel
from requests import Response
from typing import Dict
from urllib.parse import urljoin, urlencode
from lago_python_client.version import LAGO_VERSION


class BaseClient:
    RESPONSE_SUCCESS_CODES = [200, 201, 202, 204]

    def __init__(self, base_url: str, api_key: str):
        self.base_url = base_url
        self.api_key = api_key

    def find(self, resource_id: str, params: Dict = None):
        api_resource = self.api_resource() + '/' + resource_id
        query_url = urljoin(self.base_url, api_resource)

        data = None
        if params is not None:
            data = json.dumps(params)

        api_response = requests.get(query_url, data=data, headers=self.headers())
        data = self.handle_response(api_response).json().get(self.root_name())

        return self.prepare_response(data)

    def find_all(self, options: Dict = None):
        if options:
            api_resource = self.api_resource() + '?' + urlencode(options)
        else:
            api_resource = self.api_resource()

        query_url = urljoin(self.base_url, api_resource)

        api_response = requests.get(query_url, headers=self.headers())
        data = self.handle_response(api_response).json()

        return self.prepare_index_response(data)

    def destroy(self, resource_id: str):
        api_resource = self.api_resource() + '/' + resource_id
        query_url = urljoin(self.base_url, api_resource)

        api_response = requests.delete(query_url, headers=self.headers())
        data = self.handle_response(api_response).json().get(self.root_name())

        return self.prepare_response(data)

    def create(self, input_object: BaseModel):
        query_url = urljoin(self.base_url, self.api_resource())
        query_parameters = {
            self.root_name(): input_object.dict()
        }
        data = json.dumps(query_parameters)
        api_response = requests.post(query_url, data=data, headers=self.headers())
        data = self.handle_response(api_response)

        if data is None:
            return True
        else:
            return self.prepare_response(data.json().get(self.root_name()))

    def update(self, input_object: BaseModel, identifier: str = None):
        api_resource = self.api_resource()

        if identifier is not None:
            api_resource = api_resource + '/' + identifier

        query_url = urljoin(self.base_url, api_resource)
        query_parameters = {
            self.root_name(): input_object.dict(exclude_none=True)
        }
        data = json.dumps(query_parameters)
        api_response = requests.put(query_url, data=data, headers=self.headers())
        data = self.handle_response(api_response).json().get(self.root_name())

        return self.prepare_response(data)

    def headers(self):
        bearer = "Bearer " + self.api_key
        user_agent = 'Lago Python v' + LAGO_VERSION
        headers = {
            'Content-type': 'application/json',
            'Authorization': bearer,
            'User-agent': user_agent
        }

        return headers

    def handle_response(self, response: Response):
        if response.status_code in BaseClient.RESPONSE_SUCCESS_CODES:
            if response.text:
                return response
            else:
                return None
        else:
            raise LagoApiError(
                "URI: %s. Status code: %s. Response: %s." % (
                    response.request.url, response.status_code, response.text)
            )

    def prepare_index_response(self, data: Dict):
        collection = []

        for el in data[self.api_resource()]:
            collection.append(self.prepare_response(el))

        response = {
            self.api_resource(): collection,
            'meta': data['meta']
        }

        return response


class LagoApiError(Exception):
    ...



import requests
import json

from .base_client import BaseClient
from pydantic import BaseModel
from requests import Response
from lago_python_client.models.wallet_transaction import WalletTransactionResponse
from typing import Dict
from urllib.parse import urljoin, urlencode


class WalletTransactionClient(BaseClient):
    def api_resource(self):
        return 'wallet_transactions'

    def root_name(self):
        return 'wallet_transactions'

    def create(self, input_object: BaseModel):
        query_url = urljoin(self.base_url, self.api_resource())
        query_parameters = {
            'wallet_transaction': input_object.dict()
        }
        data = json.dumps(query_parameters)
        api_response = requests.post(query_url, data=data, headers=self.headers())
        data = self.handle_response(api_response)

        return self.prepare_response(data.json().get(self.root_name()))

    def prepare_object_response(self, data: Dict):
        return WalletTransactionResponse.parse_obj(data)

    def prepare_response(self, data):
        collection = []

        for el in data:
            collection.append(self.prepare_object_response(el))

        response = {
            self.api_resource(): collection
        }

        return response



from pydantic import BaseModel
from typing import Optional, List
from .invoice import FeeResponse

class ItemResponse(BaseModel):
    lago_id: Optional[str]
    credit_amount_cents: Optional[int]
    credit_amount_currency: Optional[str]
    refund_amount_cents: Optional[int]
    refund_amount_currency: Optional[str]
    fee: Optional[FeeResponse]

class ItemsResponse(BaseModel):
    __root__: List[ItemResponse]

class CreditNoteResponse(BaseModel):
    lago_id: Optional[str]
    sequential_id: Optional[int]
    number: Optional[str]
    lago_invoice_id: Optional[str]
    invoice_number: Optional[str]
    credit_status: Optional[str]
    refund_status: Optional[str]
    reason: Optional[str]
    total_amount_cents: Optional[int]
    total_amount_currency: Optional[str]
    credit_amount_cents: Optional[int]
    credit_amount_currency: Optional[str]
    balance_amount_cents: Optional[int]
    balance_amount_currency: Optional[str]
    refund_amount_cents: Optional[int]
    refund_amount_currency: Optional[str]
    vat_amount_cents: Optional[str]
    vat_amount_currency: Optional[str]
    sub_total_vat_excluded_amount_cents: Optional[str]
    sub_total_vat_excluded_amount_currency: Optional[str]
    file_url: Optional[str]
    created_at: Optional[str]
    updated_at: Optional[str]
    items: Optional[ItemsResponse]

class Item(BaseModel):
    credit_amount_cents: Optional[int]
    refund_amount_cents: Optional[int]
    fee_id: Optional[str]

class Items(BaseModel):
    __root__: List[Item]

class CreditNote(BaseModel):
    reason: Optional[str]
    items: Optional[Items]

class CreditNoteUpdate(BaseModel):
    refund_status: Optional[str]



from .base_client import BaseClient
from lago_python_client.models.add_on import AddOnResponse
from typing import Dict


class AddOnClient(BaseClient):
    def api_resource(self):
        return 'add_ons'

    def root_name(self):
        return 'add_on'

    def prepare_response(self, data: Dict):
        return AddOnResponse.parse_obj(data)



from lago_python_client.clients.applied_add_on_client import AppliedAddOnClient
from lago_python_client.clients.applied_coupon_client import AppliedCouponClient
from lago_python_client.clients.billable_metric_client import BillableMetricClient
from lago_python_client.clients.coupon_client import CouponClient
from lago_python_client.clients.credit_note_client import CreditNoteClient
from lago_python_client.clients.plan_client import PlanClient
from lago_python_client.clients.add_on_client import AddOnClient
from lago_python_client.clients.organization_client import OrganizationClient
from lago_python_client.clients.event_client import EventClient
from lago_python_client.clients.subscription_client import SubscriptionClient
from lago_python_client.clients.customer_client import CustomerClient
from lago_python_client.clients.invoice_client import InvoiceClient
from lago_python_client.clients.webhook_client import WebhookClient
from lago_python_client.clients.wallet_client import WalletClient
from lago_python_client.clients.wallet_transaction_client import WalletTransactionClient



from .base_client import BaseClient
from lago_python_client.models.organization import OrganizationResponse
from typing import Dict


class OrganizationClient(BaseClient):
    def api_resource(self):
        return 'organizations'

    def root_name(self):
        return 'organization'

    def prepare_response(self, data: Dict):
        return OrganizationResponse.parse_obj(data)



import requests

from .base_client import BaseClient
from lago_python_client.models.invoice import InvoiceResponse
from typing import Dict
from urllib.parse import urljoin
from requests import Response


class InvoiceClient(BaseClient):
    def api_resource(self):
        return 'invoices'

    def root_name(self):
        return 'invoice'

    def prepare_response(self, data: Dict):
        return InvoiceResponse.parse_obj(data)

    def download(self, resource_id: str):
        api_resource = self.api_resource() + '/' + resource_id + '/download'
        query_url = urljoin(self.base_url, api_resource)
        api_response = requests.post(query_url, headers=self.headers())
        data = self.handle_response(api_response).json().get(self.root_name())

        return self.prepare_response(data)


from pydantic import BaseModel, Field
from typing import Optional


class Coupon(BaseModel):
    name: Optional[str]
    code: Optional[str]
    amount_cents: Optional[int]
    amount_currency: Optional[str]
    expiration: Optional[str]
    expiration_at: Optional[str]
    percentage_rate: Optional[float]
    coupon_type: Optional[str]
    reusable: Optional[bool]
    frequency: Optional[str]
    frequency_duration: Optional[int]


class CouponResponse(BaseModel):
    lago_id: str
    name: str
    code: str
    amount_cents: int
    amount_currency: str
    created_at: str
    expiration: str
    expiration_at: Optional[str]
    percentage_rate: Optional[float]
    coupon_type: Optional[str]
    reusable: Optional[bool]
    frequency: Optional[str]
    frequency_duration: Optional[int]



from pydantic import BaseModel, Field
from typing import Optional, List


class Event(BaseModel):
    transaction_id: str
    external_customer_id: Optional[str]
    external_subscription_id: Optional[str]
    code: str
    timestamp: Optional[int]
    properties: Optional[dict]


class BatchEvent(BaseModel):
    transaction_id: str
    external_customer_id: Optional[str]
    external_subscription_ids: List[str]
    code: str
    timestamp: Optional[int]
    properties: Optional[dict]


class EventResponse(BaseModel):
    lago_id: str
    transaction_id: str
    external_customer_id: Optional[str]
    lago_customer_id: Optional[str]
    lago_subscription_id: Optional[str]
    external_subscription_id: Optional[str]
    code: str
    timestamp: str
    properties: Optional[dict]
    created_at: str



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import Customer, CustomerBillingConfiguration
from lago_python_client.clients.base_client import LagoApiError


def create_customer():
    return Customer(
        external_id='5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba',
        name='Gavin Belson',
        currency='EUR',
        billing_configuration=CustomerBillingConfiguration(
            payment_provider='stripe',
            provider_customer_id='cus_12345',
            vat_rate=12.5,
            sync_with_provider=True
        )
    )

def mock_response(mock='customer'):
    this_dir = os.path.dirname(os.path.abspath(__file__))
    my_data_path = os.path.join(this_dir, 'fixtures/' + mock + '.json')

    with open(my_data_path, 'r') as customer_response:
        return customer_response.read()

class TestCustomerClient(unittest.TestCase):
    def test_valid_create_customers_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/customers', text=mock_response())
            response = client.customers().create(create_customer())

        self.assertEqual(response.external_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
        self.assertEqual(response.name, 'Gavin Belson')
        self.assertEqual(response.email, 'dinesh@piedpiper.test')
        self.assertEqual(response.currency, 'EUR')
        self.assertEqual(response.billing_configuration.payment_provider, 'stripe')
        self.assertEqual(response.billing_configuration.provider_customer_id, 'cus_12345')
        self.assertEqual(response.billing_configuration.vat_rate, 12.5)
        self.assertEqual(response.billing_configuration.sync_with_provider, True)

    def test_invalid_create_customers_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/customers', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.customers().create(create_customer())


    def test_valid_current_usage(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET',
                           'https://api.getlago.com/api/v1/customers/external_customer_id/current_usage?external_subscription_id=123',
                           text=mock_response('customer_usage'))
            response = client.customers().current_usage('external_customer_id', '123')

        self.assertEqual(response.from_datetime, '2022-07-01T00:00:00Z')
        self.assertEqual(len(response.charges_usage), 1)
        self.assertEqual(response.charges_usage[0].units, 1.0)

    def test_invalid_current_usage(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET',
                           'https://api.getlago.com/api/v1/customers/invalid_customer/current_usage?external_subscription_id=123',
                           status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.customers().current_usage('invalid_customer', '123')


if __name__ == '__main__':
    unittest.main()



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import WalletTransaction
from lago_python_client.clients.base_client import LagoApiError


def wallet_transaction_object():
    return WalletTransaction(
        wallet_id='123',
        paid_credits='10',
        granted_credits='10'
    )


def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/wallet_transaction.json')

    with open(data_path, 'r') as wallet_transaction_response:
        return wallet_transaction_response.read()


class TestWalletTransactionClient(unittest.TestCase):
    def test_valid_create_wallet_transaction_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/wallet_transactions', text=mock_response())
            response = client.wallet_transactions().create(wallet_transaction_object())

        self.assertEqual(response['wallet_transactions'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1111')
        self.assertEqual(response['wallet_transactions'][1].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1222')

    def test_invalid_create_wallet_transaction_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/wallet_transactions', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.wallet_transactions().create(wallet_transaction_object())


if __name__ == '__main__':
    unittest.main()



import unittest

from lago_python_client.client import Client


class TestClient(unittest.TestCase):
    def test_base_url_when_api_url_is_given(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d',
                        api_url='https://example.com/')

        self.assertEqual(client.base_api_url(), 'https://example.com/api/v1/')

    def test_base_url_when_api_url_is_not_given(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        self.assertEqual(client.base_api_url(), 'https://api.getlago.com/api/v1/')


if __name__ == '__main__':
    unittest.main()



from typing import List
from pydantic import BaseModel, Field


class Metric(BaseModel):
  lago_id: str
  name: str
  code: str
  aggregation_type: str


class ChargeObject(BaseModel):
  lago_id: str
  charge_model: str


class ChargeUsage(BaseModel):
  units: float
  amount_cents: int
  amount_currency: str
  charge: ChargeObject
  billable_metric: Metric


class CustomerUsageResponse(BaseModel):
  from_datetime: str
  to_datetime: str
  issuing_date: str
  amount_cents: int
  amount_currency: str
  total_amount_cents: int
  total_amount_currency: str
  vat_amount_cents: int
  vat_amount_currency: str
  charges_usage: List[ChargeUsage]



from lago_python_client.clients.applied_add_on_client import AppliedAddOnClient
from lago_python_client.clients.applied_coupon_client import AppliedCouponClient
from lago_python_client.clients.billable_metric_client import BillableMetricClient
from lago_python_client.clients.coupon_client import CouponClient
from lago_python_client.clients.group_client import GroupClient
from lago_python_client.clients.credit_note_client import CreditNoteClient
from lago_python_client.clients.plan_client import PlanClient
from lago_python_client.clients.add_on_client import AddOnClient
from lago_python_client.clients.organization_client import OrganizationClient
from lago_python_client.clients.subscription_client import SubscriptionClient
from lago_python_client.clients.customer_client import CustomerClient
from lago_python_client.clients.invoice_client import InvoiceClient
from lago_python_client.clients.event_client import EventClient
from lago_python_client.clients.webhook_client import WebhookClient
from lago_python_client.clients.wallet_client import WalletClient
from lago_python_client.clients.wallet_transaction_client import WalletTransactionClient
from urllib.parse import urljoin


class Client:
    BASE_URL = 'https://api.getlago.com/'
    API_PATH = 'api/v1/'

    def __init__(self, api_key: str = None, api_url: str = None):
        self.api_key = api_key
        self.api_url = api_url

    def base_api_url(self):
        if self.api_url is None:
            return urljoin(Client.BASE_URL, Client.API_PATH)
        else:
            return urljoin(self.api_url, Client.API_PATH)

    def events(self):
        return EventClient(self.base_api_url(), self.api_key)

    def groups(self):
        return GroupClient(self.base_api_url(), self.api_key)

    def subscriptions(self):
        return SubscriptionClient(self.base_api_url(), self.api_key)

    def credit_notes(self):
        return CreditNoteClient(self.base_api_url(), self.api_key)

    def customers(self):
        return CustomerClient(self.base_api_url(), self.api_key)

    def invoices(self):
        return InvoiceClient(self.base_api_url(), self.api_key)

    def applied_coupons(self):
        return AppliedCouponClient(self.base_api_url(), self.api_key)

    def applied_add_ons(self):
        return AppliedAddOnClient(self.base_api_url(), self.api_key)

    def billable_metrics(self):
        return BillableMetricClient(self.base_api_url(), self.api_key)

    def coupons(self):
        return CouponClient(self.base_api_url(), self.api_key)

    def plans(self):
        return PlanClient(self.base_api_url(), self.api_key)

    def add_ons(self):
        return AddOnClient(self.base_api_url(), self.api_key)

    def organizations(self):
        return OrganizationClient(self.base_api_url(), self.api_key)

    def webhooks(self):
        return WebhookClient(self.base_api_url(), self.api_key)

    def wallets(self):
        return WalletClient(self.base_api_url(), self.api_key)

    def wallet_transactions(self):
        return WalletTransactionClient(self.base_api_url(), self.api_key)



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import Subscription
from lago_python_client.clients.base_client import LagoApiError


def create_subscription():
    return Subscription(external_customer_id='5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba', plan_code='eartha lynch',
                        external_id='code', billing_time='anniversary', subscription_date='2022-04-29')


def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    my_data_path = os.path.join(this_dir, 'fixtures/subscription.json')

    with open(my_data_path, 'r') as subscription_response:
        return subscription_response.read()


def mock_collection_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/subscription_index.json')

    with open(data_path, 'r') as subscription_response:
        return subscription_response.read()


class TestSubscriptionClient(unittest.TestCase):
    def test_valid_create_subscriptions_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/subscriptions', text=mock_response())
            response = client.subscriptions().create(create_subscription())

        self.assertEqual(response.external_customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
        self.assertEqual(response.status, 'active')
        self.assertEqual(response.plan_code, 'eartha lynch')
        self.assertEqual(response.billing_time, 'anniversary')
        self.assertEqual(response.subscription_date, '2022-04-29')

    def test_invalid_create_subscriptions_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/subscriptions', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.subscriptions().create(create_subscription())

    def test_valid_update_subscription_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        identifier = 'sub_id'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/subscriptions/' + identifier,
                           text=mock_response())
            response = client.subscriptions().update(Subscription(name='name'), identifier)

        self.assertEqual(response.external_customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
        self.assertEqual(response.status, 'active')
        self.assertEqual(response.plan_code, 'eartha lynch')
        self.assertEqual(response.billing_time, 'anniversary')
        self.assertEqual(response.subscription_date, '2022-04-29')

    def test_invalid_update_subscription_request(self):
        client = Client(api_key='invalid')
        identifier = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/subscriptions/' + identifier,
                           status_code=401,
                           text='')

            with self.assertRaises(LagoApiError):
                client.subscriptions().update(Subscription(name='name'), identifier)

    def test_valid_destroy_subscription_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        identifier = 'sub_id'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/subscriptions/' + identifier, text=mock_response())
            response = client.subscriptions().destroy(identifier)

        self.assertEqual(response.external_customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
        self.assertEqual(response.status, 'active')
        self.assertEqual(response.plan_code, 'eartha lynch')

    def test_invalid_destroy_subscription_request(self):
        client = Client(api_key='invalid')
        identifier = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/subscriptions/' + identifier,
                           status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.subscriptions().destroy(identifier)

    def test_valid_find_all_subscription_request_with_options(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/subscriptions?external_customer_id=123',
                           text=mock_collection_response())
            response = client.subscriptions().find_all({'external_customer_id': '123'})

        self.assertEqual(response['subscriptions'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_invalid_find_all_subscription_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/subscriptions', status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.subscriptions().find_all()


if __name__ == '__main__':
    unittest.main()



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import Event
from lago_python_client.models import BatchEvent
from lago_python_client.clients.base_client import LagoApiError


def create_event():
    return Event(external_customer_id='5eb02857-a71e-4ea2-bcf9-57d8885990ba', code='123', transaction_id='123')

def create_batch_event():
    return BatchEvent(external_subscription_ids=['88u02857-a71e-4ea2-bcf9-57d8885990ba'], code='123', transaction_id='123')

def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/event.json')

    with open(data_path, 'r') as event_response:
        return event_response.read()

class TestEventClient(unittest.TestCase):
    def test_valid_create_events_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/events', text='')
            response = client.events().create(create_event())

        self.assertEqual(response, True)

    def test_invalid_create_events_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/events', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.events().create(create_event())

    def test_valid_create_batch_events_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/events/batch', text='')
            response = client.events().batch_create(create_batch_event())

        self.assertEqual(response, True)

    def test_invalid_create_batch_events_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/events/batch', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.events().batch_create(create_batch_event())

    def test_valid_find_event_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        event_id = '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/events/' + event_id, text=mock_response())
            response = client.events().find(event_id)

        self.assertEqual(response.lago_id, event_id)

    def test_invalid_find_events_request(self):
        client = Client(api_key='invalid')
        event_id = 'INVALID_EVENT'

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/events', status_code=401, text='')
            m.register_uri('GET', 'https://api.getlago.com/api/v1/events/' + event_id, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.events().find(event_id)

if __name__ == '__main__':
    unittest.main()



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import Coupon
from lago_python_client.clients.base_client import LagoApiError


def coupon_object():
    return Coupon(
        name='name',
        code='code_first',
        amount_cents=1000,
        amount_currency='EUR',
        expiration='no_expiration',
        expiration_at="2022-08-08T23:59:59Z",
        coupon_type="fixed_amount",
        reusable=False,
        frequency="once"
    )


def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/coupon.json')

    with open(data_path, 'r') as coupon_response:
        return coupon_response.read()


def mock_collection_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/coupon_index.json')

    with open(data_path, 'r') as coupon_response:
        return coupon_response.read()


class TestCouponClient(unittest.TestCase):
    def test_valid_create_coupon_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/coupons', text=mock_response())
            response = client.coupons().create(coupon_object())

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, 'coupon_code')

    def test_invalid_create_coupon_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/coupons', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.coupons().create(coupon_object())

    def test_valid_update_coupon_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'coupon_code'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/coupons/' + code,
                           text=mock_response())
            response = client.coupons().update(coupon_object(), code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_update_coupon_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/coupons/' + code,
                           status_code=401,
                           text='')

            with self.assertRaises(LagoApiError):
                client.coupons().update(coupon_object(), code)

    def test_valid_find_coupon_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'coupon_code'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/coupons/' + code, text=mock_response())
            response = client.coupons().find(code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_find_coupon_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/coupons/' + code, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.coupons().find(code)

    def test_valid_destroy_coupon_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
        code = 'coupon_code'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/coupons/' + code, text=mock_response())
            response = client.coupons().destroy(code)

        self.assertEqual(response.lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response.code, code)

    def test_invalid_destroy_coupon_request(self):
        client = Client(api_key='invalid')
        code = 'invalid'

        with requests_mock.Mocker() as m:
            m.register_uri('DELETE', 'https://api.getlago.com/api/v1/coupons/' + code, status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.coupons().destroy(code)

    def test_valid_find_all_coupon_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/coupons', text=mock_collection_response())
            response = client.coupons().find_all()

        self.assertEqual(response['coupons'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1111')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_valid_find_all_coupon_request_with_options(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/coupons?per_page=2&page=1', text=mock_collection_response())
            response = client.coupons().find_all({'per_page': 2, 'page': 1})

        self.assertEqual(response['coupons'][1].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac1222')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_invalid_find_all_coupon_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/coupons', status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.coupons().find_all()


if __name__ == '__main__':
    unittest.main()



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import Organization, OrganizationBillingConfiguration
from lago_python_client.clients.base_client import LagoApiError


def organization_object():
    return Organization(
        webhook_url="https://test-example.example",
        billing_configuration=OrganizationBillingConfiguration(
            invoice_footer='footer',
            vat_rate=20
        )
    )


def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/organization.json')

    with open(data_path, 'r') as organization_response:
        return organization_response.read()


class TestOrganizationClient(unittest.TestCase):
    def test_valid_update_organization_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/organizations',
                           text=mock_response())
            response = client.organizations().update(organization_object())

        self.assertEqual(response.name, 'Hooli')

    def test_invalid_update_organization_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('PUT',
                           'https://api.getlago.com/api/v1/organizations',
                           status_code=401,
                           text='')

            with self.assertRaises(LagoApiError):
                client.organizations().update(organization_object())


if __name__ == '__main__':
    unittest.main()



from lago_python_client.models.applied_add_on import AppliedAddOn
from lago_python_client.models.applied_coupon import AppliedCoupon
from lago_python_client.models.billable_metric import BillableMetric, BillableMetricGroup
from lago_python_client.models.coupon import Coupon
from lago_python_client.models.credit_note import Item, Items, CreditNote, CreditNoteUpdate
from lago_python_client.models.plan import Plan, Charges, Charge
from lago_python_client.models.add_on import AddOn
from lago_python_client.models.organization import Organization, OrganizationBillingConfiguration
from lago_python_client.models.event import Event, BatchEvent
from lago_python_client.models.customer import Customer, CustomerBillingConfiguration
from lago_python_client.models.invoice import InvoicePaymentStatusChange
from lago_python_client.models.subscription import Subscription
from lago_python_client.models.customer_usage import Metric, ChargeObject, ChargeUsage, CustomerUsageResponse
from lago_python_client.models.wallet import Wallet
from lago_python_client.models.wallet_transaction import WalletTransaction



from pydantic import BaseModel, Field
from typing import Optional, List, Union

class GroupProperties(BaseModel):
    group_id: Optional[str]
    values: Optional[dict]

class Charge(BaseModel):
    id: Optional[str]
    billable_metric_id: Optional[str]
    charge_model: Optional[str]
    properties: Optional[dict]
    group_properties: Optional[GroupProperties]

class Charges(BaseModel):
    __root__: List[Charge]

class Plan(BaseModel):
    name: Optional[str]
    code: Optional[str]
    interval: Optional[str]
    description: Optional[str]
    amount_cents: Optional[int]
    amount_currency: Optional[str]
    trial_period: Optional[float]
    pay_in_advance: Optional[bool]
    bill_charges_monthly: Optional[bool]
    charges: Optional[Charges]


class PlanResponse(BaseModel):
    lago_id: str
    name: str
    created_at: str
    code: str
    interval: Optional[str]
    description: Optional[str]
    amount_cents: Optional[int]
    amount_currency: Optional[str]
    trial_period: Optional[float]
    pay_in_advance: Optional[bool]
    bill_charges_monthly: Optional[bool]
    charges: Optional[Charges]



import requests

from .base_client import BaseClient
from lago_python_client.models.customer import CustomerResponse
from lago_python_client.models.customer_usage import CustomerUsageResponse
from typing import Dict
from urllib.parse import urljoin


class CustomerClient(BaseClient):
    def api_resource(self):
        return 'customers'

    def root_name(self):
        return 'customer'

    def prepare_response(self, data: Dict):
        return CustomerResponse.parse_obj(data)

    def current_usage(self, resource_id: str, external_subscription_id: str):
        api_resource = self.api_resource() + '/' + resource_id + '/current_usage?external_subscription_id=' + external_subscription_id
        query_url = urljoin(self.base_url, api_resource)

        api_response = requests.get(query_url, headers=self.headers())
        data = self.handle_response(api_response).json().get('customer_usage')

        return CustomerUsageResponse.parse_obj(data)



import unittest
import requests_mock
import os

from lago_python_client.client import Client
from lago_python_client.models import AppliedCoupon
from lago_python_client.clients.base_client import LagoApiError


def create_applied_coupon():
    return AppliedCoupon(
        external_customer_id='5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba',
        coupon_code='Free-Lemon-Juice'
    )


def mock_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/applied_coupon.json')

    with open(data_path, 'r') as applied_coupon_response:
        return applied_coupon_response.read()


def mock_collection_response():
    this_dir = os.path.dirname(os.path.abspath(__file__))
    data_path = os.path.join(this_dir, 'fixtures/applied_coupon_index.json')

    with open(data_path, 'r') as applied_coupon_response:
        return applied_coupon_response.read()


class TestAppliedCouponClient(unittest.TestCase):
    def test_valid_create_applied_coupon_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/applied_coupons', text=mock_response())
            response = client.applied_coupons().create(create_applied_coupon())

        self.assertEqual(response.external_customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')

    def test_invalid_create_applied_coupon_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('POST', 'https://api.getlago.com/api/v1/applied_coupons', status_code=401, text='')

            with self.assertRaises(LagoApiError):
                client.applied_coupons().create(create_applied_coupon())

    def test_valid_find_all_applied_coupon_request(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/applied_coupons', text=mock_collection_response())
            response = client.applied_coupons().find_all()

        self.assertEqual(response['applied_coupons'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_valid_find_all_applied_coupon_request_with_options(self):
        client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/applied_coupons?per_page=2&page=1', text=mock_collection_response())
            response = client.applied_coupons().find_all({'per_page': 2, 'page': 1})

        self.assertEqual(response['applied_coupons'][1].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac2222')
        self.assertEqual(response['meta']['current_page'], 1)

    def test_invalid_find_all_applied_coupon_request(self):
        client = Client(api_key='invalid')

        with requests_mock.Mocker() as m:
            m.register_uri('GET', 'https://api.getlago.com/api/v1/applied_coupons', status_code=404, text='')

            with self.assertRaises(LagoApiError):
                client.applied_coupons().find_all()


if __name__ == '__main__':
    unittest.main()



from .base_client import BaseClient
from lago_python_client.models.plan import PlanResponse
from typing import Dict


class PlanClient(BaseClient):
    def api_resource(self):
        return 'plans'

    def root_name(self):
        return 'plan'

    def prepare_response(self, data: Dict):
        return PlanResponse.parse_obj(data)



import requests
import json

from .base_client import BaseClient
from lago_python_client.models.event import EventResponse
from typing import Dict

from pydantic import BaseModel
from urllib.parse import urljoin


class EventClient(BaseClient):
    def api_resource(self):
        return 'events'

    def root_name(self):
        return 'event'

    def batch_create(self, input_object: BaseModel):
        api_resource = self.api_resource() + '/batch'
        query_url = urljoin(self.base_url, api_resource)
        query_parameters = {
            self.root_name(): input_object.dict()
        }
        data = json.dumps(query_parameters)
        api_response = requests.post(query_url, data=data, headers=self.headers())
        self.handle_response(api_response)

        return True

    def prepare_response(self, data: Dict):
        return EventResponse.parse_obj(data)



from .base_client import BaseClient
from lago_python_client.models.billable_metric import BillableMetricResponse
from typing import Dict


class BillableMetricClient(BaseClient):
    def api_resource(self):
        return 'billable_metrics'

    def root_name(self):
        return 'billable_metric'

    def prepare_response(self, data: Dict):
        return BillableMetricResponse.parse_obj(data)



import requests

from .base_client import BaseClient
from lago_python_client.models.group import GroupResponse
from typing import Dict
from urllib.parse import urljoin, urlencode
from requests import Response

class GroupClient(BaseClient):
    def api_resource(self):
        return 'groups'

    def root_name(self):
        return 'group'

    def prepare_response(self, data: Dict):
        return GroupResponse.parse_obj(data)

    def find_all(self, metric_code: str, options: Dict = None):
        if options:
            api_resource = 'billable_metrics/' + metric_code + '/groups?' + urlencode(options)
        else:
            api_resource = 'billable_metrics/' + metric_code + '/groups'

        query_url = urljoin(self.base_url, api_resource)
        api_response = requests.get(query_url, headers=self.headers())
        data = self.handle_response(api_response).json()

        return self.prepare_index_response(data)



from .base_client import BaseClient
from lago_python_client.models.applied_coupon import AppliedCouponResponse
from typing import Dict


class AppliedCouponClient(BaseClient):
    def api_resource(self):
        return 'applied_coupons'

    def root_name(self):
        return 'applied_coupon'

    def prepare_response(self, data: Dict):
        return AppliedCouponResponse.parse_obj(data)



from pydantic import BaseModel, Field
from typing import Optional, List, Union

class BillableMetricGroup(BaseModel):
    key: Optional[str]
    values: Optional[List[Union[str, dict]]]

class BillableMetric(BaseModel):
    name: Optional[str]
    code: Optional[str]
    description: Optional[str]
    aggregation_type: Optional[str]
    field_name: Optional[str]
    group: Optional[BillableMetricGroup]

class BillableMetricResponse(BaseModel):
    lago_id: str
    name: str
    code: str
    description: Optional[str]
    aggregation_type: Optional[str]
    field_name: Optional[str]
    created_at: str
    group: BillableMetricGroup



from pydantic import BaseModel, Field
from typing import Optional


class AddOn(BaseModel):
    name: Optional[str]
    code: Optional[str]
    amount_cents: Optional[int]
    amount_currency: Optional[str]
    description: Optional[str]


class AddOnResponse(BaseModel):
    lago_id: str
    name: str
    code: str
    amount_cents: int
    amount_currency: str
    created_at: str
    description: Optional[str]
